==> haskell-quickcheck-assertions-0.3.0-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-assertions
version: 0.3.0
id: quickcheck-assertions-0.3.0-3lSUU6S81XiK9gzwVcHdhr
key: quickcheck-assertions-0.3.0-3lSUU6S81XiK9gzwVcHdhr
license: LGPL-3.0-only
maintainer: s9gf4ult@gmail.com
author: Aleksey Uymanov
homepage: https://github.com/s9gf4ult/quickcheck-assertions
synopsis: HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit
category: Testing
abi: 71babb1adc2a21eb183b3019a1be197c
exposed: True
exposed-modules:
    Test.QuickCheck.Assertions
import-dirs: /usr/lib/ghc-8.4.3/site-local/quickcheck-assertions-0.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/quickcheck-assertions-0.3.0
hs-libraries: HSquickcheck-assertions-0.3.0-3lSUU6S81XiK9gzwVcHdhr
depends:
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46
    pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao
abi-depends: QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46=58ee7693c3f851924adb1977b480388a
             pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao=6113716a5efda4345adf3bac9f3dc9b0
haddock-interfaces: /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-assertions-0.3.0-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-assertions
version: 0.3.0
id: quickcheck-assertions-0.3.0-HG9wm2kjjygBMtTbLCD3Pi
key: quickcheck-assertions-0.3.0-HG9wm2kjjygBMtTbLCD3Pi
license: LGPL-3.0-only
maintainer: s9gf4ult@gmail.com
author: Aleksey Uymanov
homepage: https://github.com/s9gf4ult/quickcheck-assertions
synopsis: HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit
category: Testing
abi: d1cd48e1319e426aa4aa711acb26d340
exposed: True
exposed-modules:
    Test.QuickCheck.Assertions
import-dirs: /usr/lib/ghc-8.4.3/site-local/quickcheck-assertions-0.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/quickcheck-assertions-0.3.0
hs-libraries: HSquickcheck-assertions-0.3.0-HG9wm2kjjygBMtTbLCD3Pi
depends:
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46
    pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao
abi-depends: QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46=58ee7693c3f851924adb1977b480388a
             pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao=6113716a5efda4345adf3bac9f3dc9b0
haddock-interfaces: /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
